@@ -246,7 +246,7 @@ pub fn test_some_range(a: int) -> bool {
         Convert integer base
         Extract into variable
         Extract into function
-        Replace with match
+        Replace if let with match
     "#]]
     .assert_eq(&expected);
 }
@@ -275,7 +275,7 @@ pub fn test_some_range(a: int) -> bool {
             Convert integer base
             Extract into variable
             Extract into function
-            Replace with match
+            Replace if let with match
         "#]]
         .assert_eq(&expected);
     }
